@@ -75,9 +75,7 @@ def from_config(ctx, config_file, verbose):
         verbose = True
 
     # initialize loggers
-    init_mult(name, config.logdir, modules=[__name__, 'reV.config',
-                                            'reV.utilities', 'rex.utilities'],
-              verbose=verbose)
+    init_mult(name, config.logdir, modules=['reV', 'rex'], verbose=verbose)
 
     # Initial log statements
     logger.info('Running reV supply curve from config '
@@ -215,8 +213,7 @@ def direct(ctx, sc_points, trans_table, fixed_charge_rate, sc_features,
 
     if ctx.invoked_subcommand is None:
         t0 = time.time()
-        init_mult(name, log_dir, modules=[__name__, 'reV.supply_curve',
-                                          'reV.handlers', 'rex'],
+        init_mult(name, log_dir, modules=['reV', 'rex'],
                   verbose=verbose)
 
         if isinstance(transmission_costs, str):
